@@ -8,6 +8,7 @@
 #             (following report of problem reported by Peng Ding) J. Fox
 # 2022-10-11: Modified error reports for hatvalue = 1, and add for
 #             hc0 and hc1. S. Weisberg
+# 2022-11-18  fixed error messages
 #-------------------------------------------------------------------------------
 
 # Heteroscedasticity-corrected standard errors (Huber/White adjustment) (J. Fox)
@@ -35,28 +36,31 @@ hccm.lm <-function (model, type = c("hc3", "hc0", "hc1", "hc2", "hc4"),
 		wts <- wts[-removed]
 		h <- h[-removed]
 	}
+# error checking 1:  check if any elements of h are > 1- sqrt(machine.eps)
+	bad <- which(h > 1 - sqrt(.Machine$double.eps))
+	if(length(bad) > 0){
+	  nms <- names(residuals(model))
+	  stop("hatvalues (leverages) equal to or very close to 1 for the following cases:\n", 
+	       if(length(bad) <=  10) paste(nms[bad], collapse=", ") else
+	         paste0(paste(nms[bad[1:10]], collapse=", "), ", ..."),"\n",
+	       "For type = 'hc1', 'hc2', or 'hc3' the hccm is undefined.\n",
+	       "For type = 'hc0' or 'hc4' the hccm is singular and therefore\n",
+	       "not a consistent estimator of the coefficient covariance matrix.")
+	}
+# end error checking 1
 	X <- model.matrix(model)[, !aliased, drop=FALSE]
 	df.res <- df.residual(model)
 	n <- length(e)
 	e <- wts*e
 	p <- ncol(X)
 	factor <- switch(type, hc0 = 1, hc1 = df.res/n,
-			hc2 = 1 - h, hc3 = (1 - h)^2, hc4 = (1 - h)^pmin(4, n * h/p))
+	             hc2 = 1 - h, hc3 = (1 - h)^2, hc4 = (1 - h)^pmin(4, n * h/p))
 	V <- V %*% t(X) %*% apply(X, 2, "*", (e^2)/factor) %*% V
-	bad <- h > 1 - sqrt(.Machine$double.eps)
-	if ((n.bad <- sum(bad)) > 0 ) {
-	  nms <- names(e)
-	  bads <- if (n.bad <= 10) {
-	    paste(nms[bad], collapse=", ")
-	  } else {
-	    paste0(paste(nms[bad[1:10]], collapse=", "), ", ...")
-	  }}
-# error checking.  hc2, hc3, hc4 may have nan's if n.bad > 1
-	  if (n.bad > 0 & any(is.nan(V)))
-	    stop("hccm estimator is singular because of ", n.bad, if (n.bad == 1) " case " else " cases ", "with hatvalue = 1:\n   ", bads)
-# for hc0, hc1 there are no nans, but V may be singular	
-    if (qr(V)$rank < p)
-      stop("hccm estimator is singular because of ", n.bad, if (n.bad == 1) " case " else " cases ", "with hatvalue = 1:\n   ", bads)
+# error checking 2:  Is V singular?
+	if (qr(V)$rank < p)
+	  stop("hccm estimator is singular with rank ", qr(V)$rank, 
+	       ".\nIt is inconsistent as an estimate of the covariance matrix\nof the regression coefficients, which has rank ", p, 
+	       ".\nThis is caused by ill-conditioning of the model matrix.")
 	V
 }
 
